==> 1.0.3.tar.gz: lib/src/utils/x_size.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

/// 距离
class D {
  static sp(double? fontSize) {
    if (fontSize == null) {
      return null;
    }
    return fontSize.sp;
  }

  static h(double? height) {
    if (height == null || height == double.infinity) {
      return height;
    }
    return height.w;
  }

  static w(double? width) {
    if (width == null || width == double.infinity) {
      return width;
    }
    return width.w;
  }
}

/// Padding
class P {
  static all(double width) {
    return EdgeInsets.all(width.w);
  }

  static hv({double? horizontal, double? vertical}) {
    return EdgeInsets.symmetric(
      horizontal: horizontal == null ? 0.0 : horizontal.w,
      vertical: vertical == null ? 0.0 : vertical.w,
    );
  }

  static only({double? left, double? top, double? right, double? bottom}) {
    return EdgeInsets.only(
      left: left == null ? 0.0 : left.w,
      right: right == null ? 0.0 : right.w,
      top: top == null ? 0.0 : top.w,
      bottom: bottom == null ? 0.0 : bottom.w,
    );
  }
}

/// 间隔
class G {
  /// 水平间隔
  static Widget h(double width) {
    return SizedBox(width: width.w);
  }

  /// 垂直间隔
  static Widget v(double height) {
    return SizedBox(height: height.w);
  }

  /// 分割线
  static Widget line = Container(
    height: 1.w,
    color: Colors.white.withOpacity(0.1),
  );

  /// 宽的分割线
  static Widget lineHigh = Container(
    height: 10.w,
    color: Colors.grey[200],
  );

  static const Widget empty = SizedBox();
}

/// 边界半径
class XRadius {
  static circular(double? radius) {
    if (radius == null) return null;
    return BorderRadius.circular(D.w(radius));
  }
}

==> 1.0.6.tar.gz: lib/src/utils/x_size.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

/// 距离
class D {
  static sp(double? fontSize) {
    if (fontSize == null) {
      return null;
    }
    return fontSize.sp;
  }

  static h(double? height) {
    if (height == null || height == double.infinity) {
      return height;
    }
    return height.w;
  }

  static w(double? width) {
    if (width == null || width == double.infinity) {
      return width;
    }
    return width.w;
  }
}

/// Padding
class P {
  static all(double width) {
    return EdgeInsets.all(width.w);
  }

  static hv({double? horizontal, double? vertical}) {
    return EdgeInsets.symmetric(
      horizontal: horizontal == null ? 0.0 : horizontal.w,
      vertical: vertical == null ? 0.0 : vertical.w,
    );
  }

  static only({double? left, double? top, double? right, double? bottom}) {
    return EdgeInsets.only(
      left: left == null ? 0.0 : left.w,
      right: right == null ? 0.0 : right.w,
      top: top == null ? 0.0 : top.w,
      bottom: bottom == null ? 0.0 : bottom.w,
    );
  }
}

/// 间隔
class G {
  /// 水平间隔
  static Widget h(double width) {
    return SizedBox(width: width.w);
  }

  /// 垂直间隔
  static Widget v(double height) {
    return SizedBox(height: height.w);
  }

  static const Widget empty = SizedBox();
}

/// 边界半径
class XRadius {
  static all(double? radius) {
    if (radius == null) return null;
    return BorderRadius.circular(D.w(radius));
  }

  static top(double? radius) {
    if (radius == null) return null;
    return BorderRadius.vertical(top: Radius.circular(radius.w));
  }

  static bottom(double? radius) {
    if (radius == null) return null;
    return BorderRadius.vertical(bottom: Radius.circular(radius.w));
  }

  static left(double? radius) {
    if (radius == null) return null;
    return BorderRadius.horizontal(left: Radius.circular(radius.w));
  }

  static right(double? radius) {
    if (radius == null) return null;
    return BorderRadius.horizontal(right: Radius.circular(radius.w));
  }

  static only({
    double? topLeft,
    double? topRight,
    double? bottomLeft,
    double? bottomRight,
  }) {
    return BorderRadius.only(
      topLeft: topLeft == null ? Radius.zero : Radius.circular(topLeft.w),
      topRight: topRight == null ? Radius.zero : Radius.circular(topRight.w),
      bottomLeft:
          bottomLeft == null ? Radius.zero : Radius.circular(bottomLeft.w),
      bottomRight:
          bottomRight == null ? Radius.zero : Radius.circular(bottomRight.w),
    );
  }
}
